HandleTableInner

Struct HandleTableInner 

struct HandleTableInner {
    handles: Box<[Option<KernelObject>; 1024]>,
    metadata: Box<[Option<HandleMetadata>; 1024]>,
    free_handles: Vec<Handle>,
}
Internal structure containing the actual handle table data. This is wrapped in Arc<RwLock<…>> to enable sharing between tasks.

Fields

handles: Box<[Option<KernelObject>; 1024]>

Fixed-size handle table allocated on heap to avoid stack overflow

metadata: Box<[Option<HandleMetadata>; 1024]>

Metadata for each handle allocated on heap to avoid stack overflow

free_handles: Vec<Handle>

Stack of available handle numbers for O(1) allocation